| StatusSetter | R Documentation |
Internal class that manages authors' status.
plume::NameHandler -> plume::PlumeHandler -> StatusSetter
new()StatusSetter$new(..., by)
set_corresponding_authors()Set corresponding authors.
StatusSetter$set_corresponding_authors(..., .by, by = deprecated())
...One or more unquoted expressions separated by commas.
Expressions matching values in the column defined by by/.by
determine corresponding authors. Matching of values is case-
insensitive.
.byVariable used to set corresponding authors. By default, uses authors' id.
byPlease use the .by parameter instead.
The class instance.
clone()The objects of this class are cloneable with this method.
StatusSetter$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.