Internal class extending StatusSetter for PlumeQuarto.
plume::NameHandler -> plume::PlumeHandler -> plume::StatusSetter -> StatusSetterPlumeQuarto
set_cofirst_authors()Set co-first authors.
StatusSetterPlumeQuarto$set_cofirst_authors(..., .by = NULL)...One or more unquoted expressions separated by commas.
Expressions matching values in the column defined by by or .by
determine co-first authors. Matching of values is case-insensitive and
dot-agnostic.
.byVariable used to specify which authors contributed equally to the work. By default, uses authors' id.
The class instance.
set_equal_contributor()This method has been deprecated in favour of set_cofirst_authors().
StatusSetterPlumeQuarto$set_equal_contributor(
...,
.by = NULL,
by = deprecated()
)...One or more unquoted expressions separated by commas.
Expressions matching values in the column defined by by/.by
determine equal contributors. Matching of values is case-insensitive.
.byVariable used to specify which authors are equal contributors. By default, uses authors' id.
byPlease use the .by parameter instead.
The class instance.
set_deceased()Set deceased authors.
StatusSetterPlumeQuarto$set_deceased(..., .by = NULL, by = deprecated())...One or more unquoted expressions separated by commas.
Expressions matching values in the column defined by by or .by
determine deceased authors. Matching of values is case-insensitive and
dot-agnostic.
.byVariable used to specify whether an author is deceased or not. By default, uses authors' id.
byPlease use the .by parameter instead.
The class instance.
clone()The objects of this class are cloneable with this method.
StatusSetterPlumeQuarto$clone(deep = FALSE)deepWhether to make a deep clone.